Defines DatatypeStr type to inform #voc/dstr custom reader tag.
Defines DatatypeStr type to inform #voc/dstr custom reader tag.
(datatype datatypeStr)Returns the datatype tag associated with datatypeStr.
Returns the datatype tag associated with `datatypeStr`.
A map := {(type obj) tag, ...}.
obj is a clojure value
-tag is a qname for the resource tagging the datatype of objvoc/tag method's 1-arg versionA map := {(type `obj`) `tag`, ...}.
- Where
-`obj` is a clojure value
-`tag` is a qname for the resource tagging the datatype of `obj`
- NOTE: this informs the `voc/tag` method's 1-arg version
(parse form)Returns [datum datatype] for s, or nil.
s is a string :~ datum^^datatype
datum is a stringdatatype is is a stringReturns [`datum` `datatype`] for `s`, or nil. - Where -`s` is a string :~ `datum`^^`datatype` - `datum` is a string - `datatype` is is a string
(read-DatatypeStr form)Returns an instance of DatatypeStr parsed from form.
form :- datum^^datatypeReturns an instance of DatatypeStr parsed from `form`. - Where: - `form` :- `datum`^^`datatype`
(read-DatatypeStr-cljs form)Returns a macro expression for read-DatatypeStr suitable for insertion and interpretation in cljs source.
Returns a macro expression for read-DatatypeStr suitable for insertion and interpretation in cljs source.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |