Defines LangStr type to inform #voc/lstr custom reader tag.
Defines LangStr type to inform #voc/lstr custom reader tag.
(lang langStr)Returns the language tag associated with langStr.
Returns the language tag associated with `langStr`.
An atom containing the writer used for IPrintWithWriter of cljs version of LangStr.
An atom containing the writer used for IPrintWithWriter of cljs version of LangStr.
(parse form)Returns [datum type] for s, or nil.
s is a string :~ datum^^type
datum is a stringtype is is a stringReturns [`datum` `type`] for `s`, or nil. - Where -`s` is a string :~ `datum`^^`type` - `datum` is a string - `type` is is a string
(read-LangStr form)Returns an instance of LangStr parsed from form.
Where:
form :- str@langReturns an instance of LangStr parsed from `form`. Where: - `form` :- `str`@`lang`
(read-LangStr-cljs form)Returns a macro expression for read-LangStr suitable for insertion and interpretation in cljs source.
Returns a macro expression for read-LangStr suitable for insertion and interpretation in cljs source.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |